# Legacy Notebooks

These notebooks work for `tables_io` version < 1, and are made available here for reference purposes only.

| Notebook                                                        | Description                                                         | Download                                    |
| --------------------------------------------------------------- | ------------------------------------------------------------------- | ------------------------------------------- |
| [Basic examples](project:singleTable_example.md)                | Tutorial on how to use some of the basic `tables_io` functionality. | {download}`singleTable_example.ipynb`       |
| [Iteration example](project:hdf5_iter_example.md)               | How to use `tables_io` to iterate over HDF5 files                   | {download}`hdf5_iter_example.ipynb`         |
| [Writing to an HDF5 file](project:multipleWriteHdf5_example.md) | How to write to an HDF5 file from multiple places (i.e. with MPI)   | {download}`multipleWriteHdf5_example.ipynb` |
| [TableDict example](project:tableDict_example.md)               | How to use the TableDict class.                                     | {download}`tableDict_example.ipynb`         |

```{toctree}
:hidden:
:titlesonly:

Basic examples <singleTable_example>
Iteration Example <hdf5_iter_example>
Writing to an HDF5 file <multipleWriteHdf5_example>
TableDict example <tableDict_example>
```
